summaryrefslogtreecommitdiffstats
path: root/lib/koproperty/editor.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/koproperty/editor.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/koproperty/editor.h')
-rw-r--r--lib/koproperty/editor.h41
1 files changed, 21 insertions, 20 deletions
diff --git a/lib/koproperty/editor.h b/lib/koproperty/editor.h
index 9cd794f7..677208de 100644
--- a/lib/koproperty/editor.h
+++ b/lib/koproperty/editor.h
@@ -22,12 +22,12 @@
#ifndef KPROPERTY_PROPERTYEDITOR_H
#define KPROPERTY_PROPERTYEDITOR_H
-#include <qguardedptr.h>
+#include <tqguardedptr.h>
#include "koproperty_global.h"
#include <klistview.h>
-class QSize;
+class TQSize;
namespace KoProperty {
@@ -44,15 +44,15 @@ class EditorItem;
Currently supported options are:
<ul><li> min: integer setting for minimum value of IntEdit and DoubleEdit item. Default is 0.
Set "min" to -1, if you want this special value to be allowed.</li>
- <li> minValueText: i18n'd QString used in IntEdit to set "specialValueText"
+ <li> minValueText: i18n'd TQString used in IntEdit to set "specialValueText"
widget's property</li>
<li> max: integer setting for minimum value of IntEdit item. Default is 0xffff.</li>
<li> precision: The number of decimals after the decimal point. (for DoubleEdit)</li>
<li> step : the size of the step that is taken when the user hits the up
or down buttons (for DoubleEdit) </li>
- <li> 3rdState: i18n'd QString used in BoolEdit. If not empty, the the editor's button
+ <li> 3rdState: i18n'd TQString used in BoolEdit. If not empty, the the editor's button
accept third "null" state with name equal to this string. When this value is selected,
- Widget::value() returns null QVariant. This option is used for example in the "defaultValue"
+ Widget::value() returns null TQVariant. This option is used for example in the "defaultValue"
property for a field of type boolean (in Kexi Table Designer). Third, "null" value
of the property means there is no "defaultValue" specified. </li>
</ul>
@@ -63,20 +63,21 @@ class EditorItem;
class KOPROPERTY_EXPORT Editor : public KListView
{
Q_OBJECT
+ TQ_OBJECT
public:
/*! Creates an empty Editor with \a parent as parent widget.
If \a autoSync == true, properties values are automatically synced as
soon as editor contents change (eg the user types text, etc.)
and the values are written in the property set. Otherwise, property set
is updated only when selected item changes or user presses Enter key.
Each property can overwrite this if its autoSync() == 0 or 1.
*/
- Editor(QWidget *parent=0, bool autoSync=true, const char *name=0);
+ Editor(TQWidget *tqparent=0, bool autoSync=true, const char *name=0);
virtual ~Editor();
- virtual QSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
virtual void setFocus();
virtual void setSorting( int column, bool ascending = true );
@@ -91,7 +92,7 @@ class KOPROPERTY_EXPORT Editor : public KListView
Also creates child items for composed properties.
If \a propertyToSelect is not empty, editor item for this property name
will be selected, if present. */
- void changeSet(Set *set, const QCString& propertyToSelect);
+ void changeSet(Set *set, const TQCString& propertyToSelect);
/*! Clears all items in the list.
if \a editorOnly is true, then only the current editor will be cleared,
@@ -131,7 +132,7 @@ class KOPROPERTY_EXPORT Editor : public KListView
/*! This slot is called when the user clicks the list view.
It takes care of deleting current editor and
creating a new editor for the newly selected item. */
- void slotClicked(QListViewItem *item);
+ void slotClicked(TQListViewItem *item);
/*! Undoes the last change in property editor.*/
void undo();
@@ -142,11 +143,11 @@ class KOPROPERTY_EXPORT Editor : public KListView
void hideEditor();
- void slotCollapsed(QListViewItem *item);
- void slotExpanded(QListViewItem *item);
+ void slotCollapsed(TQListViewItem *item);
+ void slotExpanded(TQListViewItem *item);
void slotColumnSizeChanged(int section);
void slotColumnSizeChanged(int section, int oldSize, int newSize);
- void slotCurrentChanged(QListViewItem *item);
+ void slotCurrentChanged(TQListViewItem *item);
void changeSetLater();
void selectItemLater();
protected:
@@ -159,22 +160,22 @@ class KOPROPERTY_EXPORT Editor : public KListView
void clearWidgetCache();
void fill();
- void addItem(const QCString &name, EditorItem *parent);
+ void addItem(const TQCString &name, EditorItem *tqparent);
void showUndoButton( bool show );
- virtual void resizeEvent(QResizeEvent *ev);
- virtual bool eventFilter( QObject * watched, QEvent * e );
- bool handleKeyPress(QKeyEvent* ev);
+ virtual void resizeEvent(TQResizeEvent *ev);
+ virtual bool eventFilter( TQObject * watched, TQEvent * e );
+ bool handleKeyPress(TQKeyEvent* ev);
- virtual bool event( QEvent * e );
+ virtual bool event( TQEvent * e );
void updateFont();
- virtual void contentsMousePressEvent( QMouseEvent * e );
+ virtual void contentsMousePressEvent( TQMouseEvent * e );
/*! Used for changeSet(). */
void changeSetInternal(Set *set, bool preservePrevSelection,
- const QCString& propertyToSelect);
+ const TQCString& propertyToSelect);
private:
EditorPrivate *d;
@@ -63,20 +63,21 @@ class EditorItem;
public:
- /*! Creates an empty Editor with \a parent as parent widget.
+ /*! Creates an empty Editor with \a tqparent as tqparent widget.
If \a autoSync == true, properties values are automatically synced as
soon as editor contents change (eg the user types text, etc.)